pub enum Error {
Retry,
ConnectionError(Error),
}Expand description
Represents an EventSource “error” event.
Note that you should not always stop reading messages when an error occurs. Many errors are benign. EventSources retry a lot, emitting errors on every failure.
Variants
Retry
The connection was closed by the server. EventSource will reopen the connection.
ConnectionError(Error)
An error occurred while connecting to the endpoint. EventSource will retry the connection.